@@ -25,7 +25,6 @@ import cStringIO
 import string
 import struct
 import sys
-import types
 
 import dns.exception
 
@@ -69,6 +68,11 @@ class AbsoluteConcatenation(dns.exception.DNSException):
     empty name to an absolute name."""
     pass
 
+class NoParent(dns.exception.DNSException):
+    """Raised if an attempt is made to get the parent of the root name
+    or the empty name."""
+    pass
+
 _escaped = {
     '"' : True,
     '(' : True,
@@ -490,6 +494,16 @@ class Name(object):
                 return self.derelativize(origin)
         else:
             return self
+
+    def parent(self):
+        """Return the parent of the name.
+        @rtype: dns.name.Name object
+        @raises NoParent: the name is either the root name or the empty name,
+        and thus has no parent.
+        """
+        if self == root or self == empty:
+            raise NoParent
+        return Name(self.labels[1:])
         
 root = Name([''])
 empty = Name([])
@@ -506,6 +520,8 @@ def from_text(text, origin = root):
     labels = []
     label = ''
     escaping = False
+    edigits = 0
+    total = 0
     if text == '@':
         text = ''
     if text:
