@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2003 Nominum, Inc.
+# Copyright (C) 2001-2005 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: node.py,v 1.17 2003/08/05 06:25:40 halley Exp $
-
 """DNS nodes.  A node is a set of rdatasets."""
 
 import StringIO
@@ -92,12 +90,13 @@ class Node(object):
         @param rdtype: The type of the rdataset
         @type rdtype: int
         @param covers: The covered type.  Usually this value is
-        dns.rdatatype.NONE, but if the rdtype is dns.rdatatype.SIG,
-        then the covers value will be the rdata type the SIG covers.
-        The library treats the SIG type as if it were a family of
-        types, e.g. SIG(A), SIG(NS), SIG(SOA).  This makes SIGs much
-        easier to work with than if SIGs covering different rdata
-        types were aggregated into a single SIG rdataset.
+        dns.rdatatype.NONE, but if the rdtype is dns.rdatatype.SIG or
+        dns.rdatatype.RRSIG, then the covers value will be the rdata
+        type the SIG/RRSIG covers.  The library treats the SIG and RRSIG
+        types as if they were a family of
+        types, e.g. RRSIG(A), RRSIG(NS), RRSIG(SOA).  This makes RRSIGs much
+        easier to work with than if RRSIGs covering different rdata
+        types were aggregated into a single RRSIG rdataset.
         @type covers: int
         @param create: If True, create the rdataset if it is not found.
         @type create: bool
