@@ -25,9 +25,6 @@ default is 'dns.rdtypes'.  Changing this value will break the library.
 chunk of hexstring that _hexify() produces before whitespace occurs.
 @type _hex_chunk: int"""
 
-import codecs
-import cStringIO
-
 import dns.exception
 import dns.rdataclass
 import dns.rdatatype
@@ -250,7 +247,7 @@ class Rdata(object):
         @param origin: The origin to use for relative names
         @type origin: dns.name.Name
         @param relativize: should names be relativized?
-        @type origin: bool
+        @type relativize: bool
         @rtype: dns.rdata.Rdata instance
         """
 
