@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Nominum, Inc.
+# Copyright (C) 2003-2005 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: PX.py,v 1.5 2003/06/30 06:08:27 halley Exp $
-
 import struct
 
 import dns.exception
@@ -31,7 +29,9 @@ class PX(dns.rdata.Rdata):
     @ivar mapx400: the mapx400 name
     @type mapx400: dns.name.Name object
     @see: RFC 2163"""
-    
+
+    __slots__ = ['preference', 'map822', 'mapx400']
+        
     def __init__(self, rdclass, rdtype, preference, map822, mapx400):
         super(PX, self).__init__(rdclass, rdtype)
         self.preference = preference
@@ -82,6 +82,10 @@ class PX(dns.rdata.Rdata):
 
     from_wire = classmethod(from_wire)
 
+    def choose_relativity(self, origin = None, relativize = True):
+        self.map822 = self.map822.choose_relativity(origin, relativize)
+        self.mapx400 = self.mapx400.choose_relativity(origin, relativize)
+
     def _cmp(self, other):
         sp = struct.pack("!H", self.preference)
         op = struct.pack("!H", other.preference)
