@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004 Nominum, Inc.
+# Copyright (C) 2003-2005 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: tokenizer.py,v 1.24 2004/03/19 00:17:27 halley Exp $
-
 """Tokenize DNS master file format"""
 
 import cStringIO
@@ -59,7 +57,7 @@ class Tokenizer(object):
     @ivar ungotten_char: The most recently ungotten character, or None.
     @type ungotten_char: string
     @ivar ungotten_token: The most recently ungotten token, or None.
-    @type ungotten_token: string
+    @type ungotten_token: (int, string) token tuple
     @ivar multiline: The current multiline level.  This value is increased
     by one every time a '(' delimiter is read, and decreased by one every time
     a ')' delimiter is read.
@@ -302,8 +300,8 @@ class Tokenizer(object):
         empty.
         
         @param token: the token to unget
-        @type token: string
-        @raises UngetBufferFull: there is already an ungotten char
+        @type token: (int, string) token tuple
+        @raises UngetBufferFull: there is already an ungotten token
         """
 
         if not self.ungotten_token is None:
