@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004 Nominum, Inc.
+# Copyright (C) 2003-2005 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: message.py,v 1.8 2004/03/19 00:17:27 halley Exp $
-
 import cStringIO
 import os
 import unittest
@@ -132,7 +130,13 @@ class MessageTestCase(unittest.TestCase):
     def test_TooBig(self):
         def bad():
             q = dns.message.from_text(query_text)
-            w = q.to_wire(max_size=15)
+            for i in xrange(0, 25):
+                rrset = dns.rrset.from_text('foo%d.' % i, 3600,
+                                            dns.rdataclass.IN,
+                                            dns.rdatatype.A,
+                                            '10.0.0.%d' % i)
+                q.additional.append(rrset)
+            w = q.to_wire(max_size=512)
         self.failUnlessRaises(dns.exception.TooBig, bad)
 
     def test_answer1(self):
@@ -152,5 +156,12 @@ class MessageTestCase(unittest.TestCase):
             m = dns.message.from_wire(badwire)
         self.failUnlessRaises(dns.message.ShortHeader, bad)
 
+    def test_RespondingToResponse(self):
+        def bad():
+            q = dns.message.make_query('foo', 'A')
+            r1 = dns.message.make_response(q)
+            r2 = dns.message.make_response(r1)
+        self.failUnlessRaises(dns.exception.FormError, bad)
+
 if __name__ == '__main__':
     unittest.main()
